local cmd = vim.cmd  -- to execute Vim commands e.g. cmd('pwd')
local fn = vim.fn    -- to call Vim functions e.g. fn.bufnr()
local g = vim.g      -- a table to access global variables
local opt = vim.opt  -- to set options
local utils = require('utils')

-------------------- EXTERNAL ------------------------------
require('my_plugins')
require('my_keymappings')
require('my_options')
require("my_autocommands")
-------------------- LUALINE -------------------------------
require('lualine').setup {
  options = {theme = 'gruvbox-material'},
  sections = {lualine_c = {'getcwd', {'filename', path = 1, file_status = true}}},
  inactive_sections = {lualine_c = {'getcwd', {'filename', path = 1, file_status = true}}}
}
-------------------- PROJECT -------------------------------
require("project_nvim").setup {
  silent_chdir = true,
}
require('telescope').load_extension('projects')
utils.map('n', '<space>p', '<cmd>Telescope projects<cr>')
-------------------- AUTOPAIRS -----------------------------
require('nvim-autopairs').setup{}
-------------------- TERMINAL ------------------------------
require('nvim-terminal').setup({
   toggle_keymap = '<leader>z',
})
-------------------- INDENT-BLANKLINE ----------------------
opt.listchars:append("eol:↴")
-- opt.listchars:append("space: ")
opt.listchars:append("trail: ")
opt.listchars:append("tab:→ ")

require("indent_blankline").setup {
  show_end_of_line = true,
  use_treesitter = true,
  show_current_context = true,
  context_patterns = {'class', 'function', 'method', 'block', '^if', '^for', '^while'},
}

